========
 gevent
========

.. image:: https://github.com/gevent/gevent/workflows/gevent%20testing/badge.svg
   :target: https://github.com/gevent/gevent/actions

.. image:: https://ci.appveyor.com/api/projects/status/bqxl88yhpho223jg?svg=true
   :target: https://ci.appveyor.com/project/denik/gevent

.. image:: https://coveralls.io/repos/gevent/gevent/badge.svg?branch=master&service=github
   :target: https://coveralls.io/github/gevent/gevent?branch=master

.. include:: docs/_about.rst

Read the documentation online at http://www.gevent.org.

Post issues on the `bug tracker`_, discuss and ask open ended
questions on the `mailing list`_, and find announcements and
information on the blog_ and `twitter (@gevent)`_.

.. include:: docs/install.rst

.. _bug tracker: https://github.com/gevent/gevent/issues
.. _mailing list: http://groups.google.com/group/gevent
.. _blog: https://dev.nextthought.com/blog/categories/gevent.html
.. _twitter (@gevent): http://twitter.com/gevent
